EthereumServerClient class

The server HTTP client

Inheritance

Constructors

EthereumServerClient()
Default constructor
EthereumServerClient.withConnectionParameters(String hostname, [int? port])
With connection parameters

Properties

admin → EthereumApiAdmin?
The Admin API
no setterinherited
eth → EthereumApiEth?
The ETH API
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
Host
getter/setter pairinherited
httpAdapter ← EthereumINetworkAdapter
HTTP Adapter
no getterinherited
id ↔ int
Transmission id
getter/setter pairinherited
lastError ↔ EthereumError
Last error
getter/setter pairinherited
port ↔ int
Connection parameters Port
getter/setter pairinherited
printError ↔ bool
Print errors, default is off
getter/setter pairinherited
rpcClient ↔ EthereumRpcClient
Json RPC client
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
Uri
no setterinherited

Methods

connectParameters(String scheme, String? hostname, [int? port]) → void
Connect by explicitly setting the connection parameters. Scheme must be either rpcScheme or rpcWsScheme
inherited
connectString(String? hostname) → void
/ Connect using a host string of the form http://thehost.com:1234, port is optional. Scheme must be http or ws
inherited
connectUri(Uri? uri) → void
Connect using a URI, port is optional
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processError(String method, Map<String, dynamic> res) → void
Error processing helper
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serverHttpAdapter → EthereumServerHTTPAdapter
The adapter
final