EthereumError class
Manages Ethereum client errors
Constructors
- EthereumError()
- Constructor
Properties
- code → int?
-
Error code
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Error transaction id
no setter
- message → String?
-
Error message
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime?
-
Error timestamp
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
updateError(
int? errorCode, String? errorMessage, int errorId) → void - Update the error details
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited